@@ -16,8 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-DATA_DIR = "/usr/share"
-LIB_DIR = "/usr/lib"
-VERSION = "0.1.21"
+DATA_DIR = "@DATADIR@"
+LIB_DIR = "@LIBDIR@"
+VERSION = "0.2.0"
 PACKAGE = "gnome-dvb-daemon"
-PYTHONDIR = "/usr/lib/python2.6/dist-packages"
+PYTHONDIR = ""
